namespace ClipboardTool
{
    #region Imports

    using System;

    using Debug = System.Diagnostics.Debug;
    using TextReader = System.IO.TextReader;
    using TextWriter = System.IO.TextWriter;
    using IDataObject = System.Windows.Forms.IDataObject;
    using DataObject = System.Windows.Forms.DataObject;
    using DataFormats = System.Windows.Forms.DataFormats;

    #endregion

    internal sealed class RtfHandler : IDataObjectHandler
    {
        public IDataObject Copy(TextReader reader)
        {
            //
            // We don't support copying RTF because we don't want to 
            // assume that whatever comes over the reader is valid RTF
            // and blindly put it on the clipboard making a claim that
            // it is. So lacking a RTF validator, we simply don't
            // support the scenario.
            //

            throw new NotSupportedException();
        }

        public bool Paste(IDataObject source, TextWriter writer)
        {
            Debug.Assert(source != null);
            Debug.Assert(writer != null);

            if (!source.GetDataPresent(DataFormats.Rtf))
                return false;

            writer.Write(source.GetData(DataFormats.Rtf).ToString());

            return true;
        }
    }
}
