namespace ClipboardTool
{
    #region Imports

    using System;

    using Debug = System.Diagnostics.Debug;
    using TextReader = System.IO.TextReader;
    using TextWriter = System.IO.TextWriter;
    using IDataObject = System.Windows.Forms.IDataObject;
    using DataObject = System.Windows.Forms.DataObject;
    using DataFormats = System.Windows.Forms.DataFormats;

    #endregion

    internal sealed class TextHandler : IDataObjectHandler
    {
        public IDataObject Copy(TextReader reader)
        {
            Debug.Assert(reader != null);

            string text = reader.ReadToEnd();

            DataObject dataObject = new DataObject();

            dataObject.SetData(DataFormats.Text, text);
            dataObject.SetData(DataFormats.UnicodeText, text);

            return dataObject;
        }

        public bool Paste(IDataObject source, TextWriter writer)
        {
            Debug.Assert(source != null);
            Debug.Assert(writer != null);

            //
            // Prefer Unicode Text over Text when pasting.
            //

            string format;

            if (source.GetDataPresent(DataFormats.UnicodeText))
            {
                format = DataFormats.UnicodeText;
            }
            else if (source.GetDataPresent(DataFormats.Text))
            {
                format = DataFormats.Text;
            }
            else
            {
                return false;
            }

            string text = source.GetData(format).ToString();
            writer.Write(text);

            return true;
        }
    }
}
